from setuptools import setup

setup(name='hptcad',
      version='0.0.1',
      description='HPTCAD',
      url='http://github.com/manstetten/hptcad',
      author='Paul Manstetten',
      author_email='manstetten@iue.tuwien.ac.at',
      license='MIT',
      packages=['hptcad'],
      zip_safe=False)
